"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureValidateCommand = void 0;
const fs_extra_1 = __importDefault(require("fs-extra"));
const path_1 = __importDefault(require("path"));
const shared_1 = require("@cubejs-backend/shared");
const schema_compiler_1 = require("@cubejs-backend/schema-compiler");
const utils_1 = require("../utils");
async function validate(options) {
    const schemaPath = options.schemaPath || (0, shared_1.getEnv)('schemaPath');
    if (!fs_extra_1.default.existsSync(path_1.default.join(process.cwd(), schemaPath))) {
        (0, utils_1.displayError)(`Schema path not found at "${path_1.default.join(process.cwd(), schemaPath)}". Please run validate command from project directory.`);
        return;
    }
    try {
        const repo = new shared_1.FileRepository(schemaPath);
        await (0, schema_compiler_1.compile)(repo, {
            allowNodeRequire: true,
        });
    }
    catch (error) {
        console.log('❌ Cube Schema validation failed');
        (0, utils_1.displayError)(error.messages);
        return;
    }
    console.log('✅ Cube Schema is valid');
}
function configureValidateCommand(program) {
    program
        .command('validate')
        .option('-p, --schema-path <schema-path>', 'Path to schema files. Default: schema')
        .description('Validate Cube schema')
        .action((options) => validate(options)
        .catch(error => (0, utils_1.displayError)(error)))
        .on('--help', () => {
        console.log('');
        console.log('Examples:');
        console.log('');
        console.log('  $ cubejs validate');
    });
}
exports.configureValidateCommand = configureValidateCommand;
//# sourceMappingURL=validate.js.map